@@ -121,8 +121,8 @@ User listing with pager, for enabling/disabling users.
 =cut
 
 sub user : Local {
-    my ( $self, $c, $user ) = @_;
-    my $iterator = $c->model("DBIC::Person")->search(
+    my ( $self, $c ) = @_;
+    my $res = $c->model("DBIC::Person")->search(
         {},
         {
             page => $c->req->param('page') || 1,
@@ -130,8 +130,9 @@ sub user : Local {
             order_by => 'active desc, login'
         }
     );
-    $c->stash->{users} = $iterator;
-    $c->stash->{pager} = $iterator->pager;
+    $c->stash->{users}    = $res;
+    $c->stash->{pager}    = $res->pager;
+    $c->stash->{template} = 'admin/user.tt';  # TT finds the template by default; added line for clarity
 }
 
 =head2 role ( .admin/role )
@@ -295,6 +296,73 @@ sub precompile_pages : Global {
     return;
 }
 
+=head2 delete
+
+Delete a page and its descendants.  This is in L<MojoMojo::Controller::Admin>
+because we are restricting page deletion to admins only for the time being.
+
+TODO: this method should reside in the Model, not in a Controller (issue #87).
+
+=cut
+
+sub delete : Global FormConfig {
+    my ( $self, $c ) = @_;
+    my $stash = $c->stash;
+    my $form  = $stash->{form};
+    $stash->{template} = 'page/delete.tt';
+    my @descendants;
+    push @descendants, {
+        name       => $_->name_orig,
+        id         => $_->id,
+        can_delete => ($_->id == 1) ? 0 : $c->check_permissions($_->path, $c->user)->{delete},
+    } for sort { $a->{path} cmp $b->{path} } $c->stash->{page}->descendants;
+    $stash->{descendants}       = \@descendants;
+    $stash->{allowed_to_delete} = ( grep {$_->{can_delete} == 0} @descendants )
+                                ? 0 : 1;
+    if ( $form->submitted_and_valid && $stash->{allowed_to_delete} ) {
+        my @deleted_pages;
+        my @ids_to_delete;
+        for my $page ( $c->stash->{page}->descendants ) {
+            push @deleted_pages, $page->name_orig;
+            push @ids_to_delete, $page->id;
+            # Handling Circular Constraints:
+            # Must set page version column to NULL (undef in Perl speak)
+            # to remove the page(id, version) -> page_version(page, version)
+            # constraint which then allows a page_version record to be deleted.
+            $page->update({version => undef});
+            # remove page from search index
+            $c->model('Search')->delete_page($page);
+        }
+        my @tables = (
+            { module => 'DBIC::PageVersion', column => 'page' },
+            { module => 'DBIC::Attachment', column => 'page' },
+            { module => 'DBIC::Comment', column => 'page' },
+            { module => 'DBIC::Link', column => [ qw(from_page to_page) ] },
+            { module => 'DBIC::RolePrivilege', column => 'page' },
+            { module => 'DBIC::Tag', column => 'page' },
+            { module => 'DBIC::WantedPage', column => 'from_page' },
+            { module => 'DBIC::Journal', column => 'pageid' },
+            { module => 'DBIC::Entry', column => 'journal' },
+            { module => 'DBIC::Content', column => 'page' },
+            { module => 'DBIC::Page', column => 'id' },
+        );
+        for my $descendant ( reverse @descendants ) {
+            for my $table ( @tables ) {
+                my $search;
+                if( ref $table->{column} ) {
+                    push @{$search}, { $_ => $descendant->{id} }
+                        for(@{$table->{column}});
+                } else {
+                    $search = { $table->{column} => $descendant->{id} }
+                }
+                $c->model( $table->{module} )->search( $search )->delete_all;
+            }
+        }
+        $stash->{deleted_pages} = \@deleted_pages;
+        $stash->{template}      = 'page/deleted.tt';
+    }
+}
+
 =head1 AUTHOR
 
 Marcus Ramberg <mramberg@cpan.org>
