@@ -51,7 +51,12 @@ formatted for inclusion in a vertical tree navigation menu.
 
 sub child_menu : Local {
     my ( $self, $c, $page_id ) = @_;
-    $c->stash->{parent_page} = $c->model("DBIC::Page")->find( $c->req->params->{page_id} );
+
+    # DBIC complains if find argument is not numeric
+    if ( $c->req->params->{page_id} =~ /^\d+$/ ) {
+      $c->stash->{parent_page} = $c->model("DBIC::Page")->find( $c->req->params->{page_id} );
+    }
+
     $c->stash->{template}    = 'child_menu.tt';
 }
 
@@ -151,9 +156,11 @@ sub untag : Local Args(1) {
     my $page = $c->stash->{page};
     die "Page " . $page . " not found" unless ref $page;
     my $tag = $c->model("DBIC::Tag")->search(
+      {
         page   => $page->id,
         person => $c->user->obj->id,
         tag    => $tagname
+      }
     )->next();
     $tag->delete() if $tag;
     $c->req->args( [$tagname] );
